#define ACE_AS_STATIC_LIBS
#define ACE_NDEBUG
#define ACE_NLOGGING
#define ACE_LACKS_ACE_SVCCONF

#if WIN9x_COMPATIBILITY
#  define ACE_HAS_WINNT4 0
#else
#  define ACE_HAS_WINNT4 1
#  define ACE_HAS_IPV6
#  ifndef _WIN32_WINNT
#    define _WIN32_WINNT 0x0501 /* Necessary for newer Platform SDK's. */
#  endif
#endif

#include "config-win32.h"
